==> IceWarpServer-9.3.2_RHEL4.tar.gz: html/syncml/inc/function.php <==
<?php
include_once 'api.php';

function mkdirtree($fpath)
{
  if($fpath!="" && !file_exists($fpath))
  {
    $fpath2=str_replace('\\','/',$fpath);
    $exparr=explode('/',$fpath2);

    for ($i=0;$i<count($exparr);$i++)
    {
      $dirline.= $exparr[$i].'/';
      if(!file_exists($dirline)) @mkdir($dirline,0750);
    }
  }
  return true;
}

function server_config()
{
  $api=new MerakAPI();
	$config_list=array();

  // Create server path
  $DataPath=$api->GetProperty('C_CalendarPath').'syncml/';
  mkdirtree($DataPath);

  // Open settings
  $file=@fopen($DataPath.'config/settings.xml','rb');
  if ($file)
  {
    $config=fread($file,10000);
    fclose($file);

    $xml_config=text_to_xml($config);
    foreach($xml_config->children() as $field)
      $config_list[$field->get_name()]=strtolower($xml_config->get_data($field->get_name()));
  }
  
  // Session defaults
  $_SESSION['Disabled']=$config_list['Disabled']?$config_list['Disabled']:0;
  $_SESSION['DataPath']=$config_list['DataPath']?$config_list['DataPath']:$DataPath;
  
  if ($config_list['LogPath'])
  	$_SESSION['LogPath']=$config_list['LogPath'];
	else
		$_SESSION['LogPath']=$api->GetProperty('C_System_Storage_Dir_LogPath').'syncml/';
		
  $_SESSION['LogLevel']=$config_list['LogLevel']?$config_list['LogLevel']:0;
  $_SESSION['RespURI']=$config_list['RespURI'];

  if (!$config_list['MaxMsgSize'])
    $config_list['MaxMsgSize']=1000000;
    
  if (!$config_list['MaxObjSize'])
    $config_list['MaxObjSize']=5000000;

	if (!$config_list['AuthType'])
	  $config_list['AuthType']=3;

  return $config_list;
}


function do_log($body,$level=1,$filename='')
{
  // Check log level
  if ($level>$_SESSION['LogLevel'])
		return;

  // Set log filename
  if (!$filename)
		$filename=$_SESSION['LogPath'].date('Ymd',time()).'.log';
  mkdirtree(dirname($filename));

  // Open log file
  $file=@fopen($filename,'a');
  if ($file)
  {
    fputs($file,date('Y-m-d H:i:s ').'sid:'.session_id().' ');
    fputs($file,$body."\r\n");
    fclose($file);
  }
}

function format_time($time)
{
 	if ($time>=60)
	{
		$min=intval($time/60);
		$time-=$min*60;
		$min.=':';

		if ($time<10)
		  $zero='0';
	}
 	
	return $min.$zero.round($time,3);
}
?>

==> IceWarpServer-9.4.0_RHEL4.tar.gz: html/syncml/inc/function.php <==
<?php
include_once 'api.php';

function mkdirtree($fpath)
{
  if($fpath!="" && !file_exists($fpath))
  {
    $fpath2=str_replace('\\','/',$fpath);
    $exparr=explode('/',$fpath2);

    for ($i=0;$i<count($exparr);$i++)
    {
      $dirline.= $exparr[$i].'/';
      if(!file_exists($dirline)) @mkdir($dirline,0750);
    }
  }
  return true;
}

function init_global_api() 
{
  global $api;
  $api = new MerakAPI();
}

function server_config()
{
  global $api;
  
	$config_list=array();

  // Create server path
  $DataPath=$api->GetProperty('C_CalendarPath').'syncml/';
  mkdirtree($DataPath);

  // Open settings
  $file=@fopen($DataPath.'config/settings.xml','rb');
  if ($file)
  {
    $config=fread($file,10000);
    fclose($file);

    $xml_config=text_to_xml($config);
    foreach($xml_config->children() as $field)
      $config_list[$field->get_name()]=strtolower($xml_config->get_data($field->get_name()));
  }
  
  // Session defaults
  $_SESSION['Disabled']=$config_list['Disabled']?$config_list['Disabled']:0;
  $_SESSION['DataPath']=$config_list['DataPath']?$config_list['DataPath']:$DataPath;
  
  if ($config_list['LogPath'])
  	$_SESSION['LogPath']=$config_list['LogPath'];
	else
		$_SESSION['LogPath']=$api->GetProperty('C_System_Storage_Dir_LogPath').'syncml/';
		
  $_SESSION['LogLevel']=$config_list['LogLevel']?$config_list['LogLevel']:0;
  $_SESSION['RespURI']=$config_list['RespURI'];

  if (!$config_list['MaxMsgSize'])
    $config_list['MaxMsgSize']=1000000;
    
  if (!$config_list['MaxObjSize'])
    $config_list['MaxObjSize']=5000000;

	if (!$config_list['AuthType'])
	  $config_list['AuthType']=3;

  return $config_list;
}

function do_log($body,$level=1)
{ 
  global $api;

	//Check log level
  if ($level>$_SESSION["LogLevel"]) 
    return;

  //ASync API log (Debug,Flush NO,MultiLine YES)
  $api->dolog(0,15,session_id(),$body,1,1); 
}

function format_time($time)
{
 	if ($time>=60)
	{
		$min=intval($time/60);
		$time-=$min*60;
		$min.=':';

		if ($time<10)
		  $zero='0';
	}
 	
	return $min.$zero.round($time,3);
}
?>
